#ifndef GSETTINGMANAGER_H
#define GSETTINGMANAGER_H

#include <QObject>
#include <QGSettings>
#include <QGuiApplication>
#include <QDebug>
#include <QFileInfo>
#include "../platforminfo.h"

//! 控制中心-个性化部分
#define CONTROL_CENTER_PERSONALISE_SETTING          "org.ukui.control-center.personalise"
#define CONTROL_CENTER_PERSONALISE_TRANS_KEY        "transparency"
#define CONTROL_CENTER_PERSONALISE_ISCHECKED_KEY    "ischecked"

class ControlCenterPersonGsetting : public QObject
{
    Q_OBJECT
public:
    ControlCenterPersonGsetting();
    ~ControlCenterPersonGsetting();

    static ControlCenterPersonGsetting *getInstance();

    double getTransparency();
    void setIschecked(bool state);

private:
    QGSettings *m_pControlCenterSetting = nullptr;

Q_SIGNALS:
    void Sig_personChanged(QString arg);

};

//! 控制中心-消息通知部分
#define CONTROL_CENTER_NOTIFICATION_SETTING        "org.ukui.control-center.noticeorigin"
#define CONTROL_CENTER_NOTIFICATION_PATH           "/org/ukui/control-center/noticeorigin/"
#define CONTROL_CENTER_NOTIFICATION_MESSAGE_KEY    "messages"
#define CONTROL_CENTER_NOTIFICATION_MAXIMINE_KEY   "maximize"
#define CONTROL_CENTER_NOTIFICATION_NAME_KEY       "nameCn"

class ControlCenterNotiGsetting : public QObject
{
    Q_OBJECT
public:
    ControlCenterNotiGsetting();
    ~ControlCenterNotiGsetting();

    static ControlCenterNotiGsetting *getInstance();

    QString getNotificationName();
    int getMixNum();
    bool getMessage();

private:
    QGSettings *m_pControlCenterSetting = nullptr;
    QList<char*> listExistsPath();

Q_SIGNALS:
    void Sig_appNotifySettingChanged();

};

//! 控制中心-面板部分
#define CONTROL_CENTER_PANEL_SETTING        "org.ukui.control-center.panel.plugins"
#define CONTROL_CENTER_PANEL_HOUR_KEY       "hoursystem"
#define CONTROL_CENTER_PANEL_DATE_KEY       "date"

#define TIME_FORMAT "12"
#define DATE_FORMAT "cn"

class ControlCenterPanelGsetting : public QObject
{
    Q_OBJECT
public:
    ControlCenterPanelGsetting();
    ~ControlCenterPanelGsetting();

    static ControlCenterPanelGsetting *getInstance();
    QString getHourSystem();
    QString getDateSystem();

private:
    QGSettings *m_pControlCenterSetting = nullptr;

Q_SIGNALS:
    void Sig_appNotifySettingChanged(QString arg);

};


//! 消息通知
#define UKUI_NOTIFICATION_SETTING         "org.notification.settings"
#define UKUI_NOTIFICATION_KEY             "showflag"
#define UKUI_NOTIFICATION_STATE_KEY       "state"

class NotificationGsetting : public QObject
{
public:
    NotificationGsetting();
    ~NotificationGsetting();

    static NotificationGsetting *getInstance();
    void setShowFlag(bool showFlag);
    void setState(bool state);

private:
    QGSettings *m_pNotificationSetting = nullptr;

};


//! 任务栏
#define UKUI_PANEL_SETTING          "org.ukui.panel.settings"
#define UKUI_PANEL_SIZE_KEY         "panelsize"
#define UKUI_PANEL_POSITION_KEY     "panelposition"

class PanelGsetting : public QObject
{
    Q_OBJECT
public:
    PanelGsetting();
    ~PanelGsetting();

    static PanelGsetting *getInstance();
    int getPanelSize();
    int getPanelPosition();

private:
    QGSettings *m_pPanelSetting = nullptr;

Q_SIGNALS:
    void Sig_panelGsettingChanged(QString key);

};

//! 锁屏
#define UKUI_SCREENSAVER_SETTING        "org.ukui.screensaver"
#define UKUI_SCREENSAVER_MESSAGE_KEY    "messageNumber"

class ScreensaverGsetting : public QObject
{

public:
    ScreensaverGsetting();
    ~ScreensaverGsetting();

    static ScreensaverGsetting *getInstance();
    void setMessageNum(int num);

private:
    QGSettings *m_pScreensaverSetting = nullptr;

};

//! ukui-style
#define UKUI_STYLE_SETTING          "org.ukui.style"
#define UKUI_STYLE_FONT_KEY         "systemFont"
#define UKUI_STYLE_FONT_SIZE_KEY    "systemFontSize"
#define UKUI_STYLE_NAME_KEY         "styleName"

class StyleGsetting : public QObject
{
    Q_OBJECT
public:
    StyleGsetting();
    ~StyleGsetting();

    static StyleGsetting *getInstance();

    QString getStyleName();
    void setStyleName(QString styleName);

private:
    QGSettings *m_pStyleSetting = nullptr;

Q_SIGNALS:
    void Sig_styleGsettingChanged(QString key);

};


//! 侧边栏快捷操作面板部分gsetting
#define QUICK_OPERATION_SETTING                       "org.ukui.quick-operation.panel"
#define QUICK_OPERATION_ENERG_KEY                     "energysavingmode"
#define QUICK_OPERATION_GSETTING_VALUE_STATUS         "disturbmodestatus"
#define QUICK_OPERATION_GSETTING_VALUE_SOUNDOFF       "disturbmodesoundoff"
#define QUICK_OPERATION_GSETTING_VALUE_NOTIFYCLOSE    "disturbmodenotifyclose"

class QuickOperationGsetting : public QObject
{
    Q_OBJECT
public:
    QuickOperationGsetting();
    ~QuickOperationGsetting();

    static QuickOperationGsetting *getInstance();

    void setEnergySavingMode(bool state);
    bool getEnergySavingMode();

    bool getModeStatus();
    void setModeStatus(bool state);
    void setModeSoundState(bool state);
    void setModeNotifyState(bool state);
private:
    QGSettings *m_pQuickOperationSetting = nullptr;

Q_SIGNALS:
    void Sig_quickOperationChanged(QString key);

};

//! 电源管理-
#define POWER_MODE_SETTING             "org.ukui.power-manager"
#define POWER_MODE_BRIGHT_AC_KEY       "brightnessAc"
#define POWER_MODE_LID_AC_KEY          "buttonLidAc"
#define POWER_MODE_LID_BATTERY_KEY     "buttonLidBattery"

class PowerModeGsetting : public QObject
{
    Q_OBJECT
public:
    PowerModeGsetting();
    ~PowerModeGsetting();

    static PowerModeGsetting *getInstance();

    void setBrightnessAc(int num);
    void setLidAc(QString arg);
    void setLidBattery(QString arg);

    int getBrightnessAc();
    QString getLidAc();
    QString getLidBattery();

private:
    QGSettings *m_pPowerModeSetting = nullptr;

};

//! 蓝牙
#define BLUE_TOOTH_SETTING        "org.ukui.bluetooth"
#define BLUE_TOOTH_SWITCH_KEY     "switch"

class BluetoothGsetting : public QObject
{
    Q_OBJECT
public:
    BluetoothGsetting();
    ~BluetoothGsetting();

    static BluetoothGsetting *getInstance();

    bool getSwitch();
    void setSwitch(bool state);

private:
    QGSettings *m_pBluetoothSetting = nullptr;

Q_SIGNALS:
    void Sig_bluetoothChanged(QString key);

};

//! mate 主题
#define GTK_STYLE_SETTING        "org.mate.interface"
#define GTK_STYLE_KEY            "gtkTheme"

#define DEFAULT_STYLE            "ukui-default"
#define BLACK_STYLE              "ukui-black"
#define WHITE_STYLE              "ukui-white"
#define DARK_STYLE               "ukui-dark"
#define LIGHT_STYLE              "ukui-light"

class GtkStyleGsetting : public QObject
{
    Q_OBJECT
public:
    GtkStyleGsetting();
    ~GtkStyleGsetting();

    static GtkStyleGsetting *getInstance();

    void setGtkTheme(QString styleName);

private:
    QGSettings *m_pGtkStyleSetting = nullptr;

};

//! 麒麟天气
#define WEATHER_GSETTING_OLD     "org.china-weather-data.settings"
#define WEATHER_GSETTING_NEW     "org.kylin-weather.settings"
#define WEATHER_GSETTING_KEY     "weather"
#define WEATHER_DESKTOP_FILE     "/etc/xdg/autostart/indicator-china-weather.desktop"

class WeatherGsetting : public QObject
{
    Q_OBJECT
public:
    WeatherGsetting();
    ~WeatherGsetting();

    static WeatherGsetting *getInstance();

    QString getWeather();
    QString getIcon();
    bool isFileExist(QString FullFileName);

private:
    QGSettings *m_pWeatherSetting = nullptr;

Q_SIGNALS:
    void Sig_weatherChanged(QString key);

};

//! 护眼中心
#define EYEPROTECTION_GSETTING             "org.ukui.eyeprotection-backend.tablemodemonitor"
#define EYEPROTECTION_TIME_KEY             "timeReminder"
#define EYEPROTECTION_DISTANCE_KEY         "distanceReminder"

class EyeprotectionGsetting : public QObject
{
    Q_OBJECT
public:
    EyeprotectionGsetting();
    ~EyeprotectionGsetting();

    static EyeprotectionGsetting *getInstance();

    bool getTimeReminder();
    bool getdistanceReminder();

    void setTimeReminder(bool state);
    void setDistanceReminder(bool state);

private:
    QGSettings *m_pEyeprotectionSetting = nullptr;

};

//! settingDaemon
#define SETTINGSDAEMON_GSETTING        "org.ukui.SettingsDaemon.plugins.color"
#define SETTINGSDAEMON_KEY             "nightLightEnabled"
#define SETTINGSDAEMON_THEME_KEY       "themeScheduleAutomatic"

class SettingsDaemonGsetting : public QObject
{
    Q_OBJECT
public:
    SettingsDaemonGsetting();
    ~SettingsDaemonGsetting();

    static SettingsDaemonGsetting *getInstance();

    bool getnightLightEnabled();
    void setnightLightEnabled(bool state);

    void setThemeScheduleAutomatic(bool state);

private:
    QGSettings *m_pSettingsDaemonSetting = nullptr;

Q_SIGNALS:
    void Sig_settingsDaemonChanged(QString key);

};

#endif // GSETTINGMANAGER_H
