﻿#include "scrollingareawidgetintel.h"

ScrollingAreaWidgetIntel::ScrollingAreaWidgetIntel(QWidget *parent) : QWidget(parent)
{
    initMemberVariable();
    initGsettingValue();
    initSlideStatus();
    initLayout();
}

void ScrollingAreaWidgetIntel::initMemberVariable()
{
    m_pHMainLayout = new QHBoxLayout();
    m_pHMainLayout->setContentsMargins(0, 0, 0, 0);
    m_pHMainLayout->setSpacing(32);
    this->setContentsMargins(0, 0, 0, 0);

    m_pVolumeWidget      = new QWidget();
    m_pVolumeWidget->setContentsMargins(0, 0, 0, 0);
    m_pVolumeIconLabel   = new QLabel();
    m_pVolumeIconLabel->setFixedSize(24, 24);

    sliderP1 = new SliderButtonIntel;
    connect(sliderP1, &SliderButtonIntel::valueChanged, this,&ScrollingAreaWidgetIntel::setVolumeSlideSlots);
    connect(sliderP1,&SliderButtonIntel::ycoordinate,this,&ScrollingAreaWidgetIntel::setVoice);

    m_pVVolumeLayout     = new QVBoxLayout();
    m_pVVolumeLayout->setContentsMargins(0, 0, 0, 0);
    m_pVVolumeLayout->setSpacing(0);

    m_pBrightNessWidget  = new QWidget();
    m_pBrightNessWidget->setContentsMargins(0, 0, 0, 0);
    m_pBrightIconLabel   = new QLabel();
    m_pBrightIconLabel->setFixedSize(24, 24);

    sliderP2 = new SliderButtonIntel;
    connect(sliderP2, &SliderButtonIntel::valueChanged, this, &ScrollingAreaWidgetIntel::setBrightSlideSlots);
    connect(sliderP2,&SliderButtonIntel::ycoordinate,this,&ScrollingAreaWidgetIntel::setBright);

    m_pBrightLayout  = new QVBoxLayout();
    m_pBrightLayout->setContentsMargins(0, 0, 0, 0);
    m_pBrightLayout->setSpacing(0);
}

void ScrollingAreaWidgetIntel::initGsettingValue()
{

    const QByteArray id_2(UKUI_VOLUME_BRIGHTNESS_GSETTING_ID);
    if (QGSettings::isSchemaInstalled(id_2)) {
        m_pVolumeLightSetting = new QGSettings(id_2);
        if (m_pVolumeLightSetting != nullptr) {
            connect(m_pVolumeLightSetting, &QGSettings::changed, this, &ScrollingAreaWidgetIntel::setSliderValue);
        }
    }

    const QByteArray id_1(KYLIN_POWER_MODE_GSETTING_VALUE);
    if (QGSettings::isSchemaInstalled(id_1)) {
        m_pBrightNessSetting = new QGSettings(id_1);
        if (m_pBrightNessSetting != nullptr) {
            connect(m_pBrightNessSetting, &QGSettings::changed, this, &ScrollingAreaWidgetIntel::setSliderValue);
        }
    }

    const QByteArray id_4(UKUI_QT_STYLE);
    if (QGSettings::isSchemaInstalled(id_4)) {
        m_style =new QGSettings(id_4);
        if (m_style != nullptr) {
            connect(m_style, &QGSettings::changed, this, &ScrollingAreaWidgetIntel::setSCrollStyle);
        }
    }

    return;
}

void ScrollingAreaWidgetIntel::initSlideStatus()
{
    const QByteArray id_2(UKUI_VOLUME_BRIGHTNESS_GSETTING_ID);
    if (QGSettings::isSchemaInstalled(id_2)){
        int value = m_pVolumeLightSetting->get(UKUI_VOLUME_KEY).toInt();
        sliderP1->setValue(value);
        mute = m_pVolumeLightSetting->get(UKUI_MUTE_KEY).toBool();
        const QByteArray id_1(KYLIN_POWER_MODE_GSETTING_VALUE);
        if (QGSettings::isSchemaInstalled(id_1)) {
            value = m_pBrightNessSetting->get(UKUI_BRIGHTNESS_KEY).toInt();
            sliderP2->setValue(value);
        }
    }

    const QByteArray id_4(UKUI_QT_STYLE);
    if (QGSettings::isSchemaInstalled(id_4)) {
        QString s = m_style->get(UKUI_STYLE_KEY).toString();
        if ( s == "ukui-black" || s == "ukui-dark") {
            sliderP1->setStyleSheet(
                        "QSlider::groove:vertical {"
                         "border: 0px none;"
                         "background: grey;"
                         "height: 230px;"
                         "width: 40px;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::handle:vertical {"
                         "background: #2FB3E8;"
                         "border: 0px none;"
                         "width: 50px;"
                         "height: 25px;"
                         "border-radius: 8px;"
                         "margin: 0px 0;"
                         "border-image:url(:/image/abcd.png);"
                         "}"

                         "QSlider::add-page:vertical {"
                         "background: #2FB3E8;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::sub-page:vertical {"
                         "background: #3E3F42;"
                         "border-radius: 8px;"
                         "}"
                        );
            sliderP2->setStyleSheet(
                        "QSlider::groove:vertical {"
                         "border: 0px none;"
                         "background: grey;"
                         "height: 230px;"
                         "width: 40px;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::handle:vertical {"
                         "background: #2FB3E8;"
                         "border: 0px none;"
                         "width: 50px;"
                         "height: 25px;"
                         "border-radius: 8px;"
                         "margin: 0px 0;"
                         "border-image:url(:/image/abcd.png);"
                         "}"

                         "QSlider::add-page:vertical {"
                         "background: #2FB3E8;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::sub-page:vertical {"
                         "background: #3E3F42;"
                         "border-radius: 8px;"
                         "}"
                        );
        }
    }
    return;
}


void ScrollingAreaWidgetIntel::initLayout()
{

    if (sliderP1->value() != 0) {
        m_pVolumeIconLabel->setPixmap(QIcon::fromTheme(KYLIN_VOLUME_PRESS_PATH).pixmap(m_pVolumeIconLabel->size()));
    } else {
        m_pVolumeIconLabel->setPixmap(QIcon::fromTheme(KYLIN_VOLUME_MUTE_PATH).pixmap(m_pVolumeIconLabel->size()));
    }
    if (mute) {
        m_pVolumeIconLabel->setPixmap(QIcon::fromTheme(KYLIN_VOLUME_MUTE_PATH).pixmap(m_pVolumeIconLabel->size()));
    }
    m_pVVolumeLayout->addWidget(sliderP1);
    m_pVVolumeLayout->addItem(new QSpacerItem(1, 5));
    m_pVVolumeLayout->addWidget(m_pVolumeIconLabel,0, Qt::AlignCenter);

    m_pVolumeWidget->setLayout(m_pVVolumeLayout);

    if (sliderP2->value() != 0) {
        m_pBrightIconLabel->setPixmap(QIcon::fromTheme(KYLIN_LIGHT_PRESS_PATH).pixmap(m_pBrightIconLabel->size()));
    } else {
        m_pBrightIconLabel->setPixmap(QIcon::fromTheme(KYLIN_LIGHT_NORMAL_PATH).pixmap(m_pBrightIconLabel->size()));
    }


    m_pBrightLayout->addWidget(sliderP2);
    m_pBrightLayout->addItem(new QSpacerItem(3, 2));
    m_pBrightLayout->addWidget(m_pBrightIconLabel,0, Qt::AlignCenter);
    m_pBrightNessWidget->setLayout(m_pBrightLayout);

    m_pHMainLayout->addWidget(m_pVolumeWidget);
    m_pHMainLayout->addWidget(m_pBrightNessWidget);
    this->setLayout(m_pHMainLayout);
}

/* 当对应的组件修改了gsetting，需修改对应滚动条的值 */
void ScrollingAreaWidgetIntel::setSliderValue(QString key)
{
    int value;
    if (key == UKUI_VOLUME_KEY) {
        value = m_pVolumeLightSetting->get(UKUI_VOLUME_KEY).toInt();
        sliderP1->setValue(value);
    } else if (key == "brightnessAc") {
        value = m_pBrightNessSetting->get(UKUI_BRIGHTNESS_KEY).toInt();
        sliderP2->setValue(value);
    }

    if (sliderP1->value() != 0) {
        m_pVolumeIconLabel->setPixmap(QIcon::fromTheme(KYLIN_VOLUME_PRESS_PATH).pixmap(m_pVolumeIconLabel->size()));
    } else {
        m_pVolumeIconLabel->setPixmap(QIcon::fromTheme(KYLIN_VOLUME_MUTE_PATH).pixmap(m_pVolumeIconLabel->size()));
    }
    if (sliderP2->value() != 0) {
        m_pBrightIconLabel->setPixmap(QIcon::fromTheme(KYLIN_LIGHT_PRESS_PATH).pixmap(m_pBrightIconLabel->size()));
    } else {
        m_pBrightIconLabel->setPixmap(QIcon::fromTheme(KYLIN_LIGHT_NORMAL_PATH).pixmap(m_pBrightIconLabel->size()));
    }

    mute = m_pVolumeLightSetting->get(UKUI_MUTE_KEY).toBool();
    if (mute) {
        m_pVolumeIconLabel->setPixmap(QIcon::fromTheme(KYLIN_VOLUME_MUTE_PATH).pixmap(m_pVolumeIconLabel->size()));
    }
}

void ScrollingAreaWidgetIntel::setVoice(int num)
{
    double x = num;
    double y = x / 230 *100;
    QString str = QString::number(y,'f',0);
    y = 100 - str.toInt();
    setVolumeSlideSlots(y);
}

void ScrollingAreaWidgetIntel::setBright(int num)
{
    double x = num;
    double y = x / 230 *100;
    QString str = QString::number(y,'f',0);
    y = 100 - str.toInt();
    setBrightSlideSlots(y);
}

void ScrollingAreaWidgetIntel::setSCrollStyle(QString key)
{
    if(key == "styleName") {
        QString s = m_style->get(UKUI_STYLE_KEY).toString();
        if ( s == "ukui-black" || s == "ukui-dark") {
            sliderP1->setStyleSheet(
                        "QSlider::groove:vertical {"
                         "border: 0px none;"
                         "background: grey;"
                         "height: 230px;"
                         "width: 40px;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::handle:vertical {"
                         "background: #2FB3E8;"
                         "border: 0px none;"
                         "width: 50px;"
                         "height: 25px;"
                         "border-radius: 8px;"
                         "margin: 0px 0;"
                         "border-image:url(:/image/abcd.png);"
                         "}"

                         "QSlider::add-page:vertical {"
                         "background: #2FB3E8;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::sub-page:vertical {"
                         "background: #3E3F42;"
                         "border-radius: 8px;"
                         "}"
                        );
            sliderP2->setStyleSheet(
                        "QSlider::groove:vertical {"
                         "border: 0px none;"
                         "background: grey;"
                         "height: 230px;"
                         "width: 40px;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::handle:vertical {"
                         "background: #2FB3E8;"
                         "border: 0px none;"
                         "width: 50px;"
                         "height: 25px;"
                         "border-radius: 8px;"
                         "margin: 0px 0;"
                         "border-image:url(:/image/abcd.png);"
                         "}"

                         "QSlider::add-page:vertical {"
                         "background: #2FB3E8;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::sub-page:vertical {"
                         "background: #3E3F42;"
                         "border-radius: 8px;"
                         "}"
                        );
        } else {
            sliderP1->setStyleSheet(

                        "QSlider::groove:vertical {"
                         "border: 0px none;"
                         "background: #F0F0F0;"
                         "height: 230px;"
                         "width: 40px;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::handle:vertical {"
                         "background: #2FB3E8;"
                         "border: 0px none;"
                         "width: 50px;"
                         "height: 25px;"
                         "border-radius: 8px;"
                         "margin: 0px 0;"
                         "border-image:url(:/image/abcd.png);"
                         "}"

                         "QSlider::add-page:vertical {"
                         "background: #2FB3E8;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::sub-page:vertical {"
                         "background: #F6F6F6;"
                         "border-radius: 8px;"
                         "}"

                     );
            sliderP2->setStyleSheet(
                        "QSlider::groove:vertical {"
                         "border: 0px none;"
                         "background: #F0F0F0;"
                         "height: 230px;"
                         "width: 40px;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::handle:vertical {"
                         "background: #2FB3E8;"
                         "border: 0px none;"
                         "width: 50px;"
                         "height: 25px;"
                         "border-radius: 8px;"
                         "margin: 0px 0;"
                         "border-image:url(:/image/abcd.png);"
                         "}"

                         "QSlider::add-page:vertical {"
                         "background: #2FB3E8;"
                         "border-radius: 8px;"
                         "}"

                         "QSlider::sub-page:vertical {"
                         "background: #F6F6F6"
                         "border-radius: 8px;"
                         "}"
                        );
        }
        
    }
}

/* 监听滑动条信号，更改声音gsetting，同步滑动条*/
void ScrollingAreaWidgetIntel::setVolumeSlideSlots(int value)
{
    const QByteArray id_2(UKUI_VOLUME_BRIGHTNESS_GSETTING_ID);
    if (QGSettings::isSchemaInstalled(id_2)) {
        m_pVolumeLightSetting->set(UKUI_VOLUME_KEY, value);
    }
    return;
}

/* 监听滑动条信号，更改亮度gsetting，同步滑动条 */
void ScrollingAreaWidgetIntel::setBrightSlideSlots(int value)
{
    const QByteArray id_1(KYLIN_POWER_MODE_GSETTING_VALUE);
    if (QGSettings::isSchemaInstalled(id_1)) {
        m_pBrightNessSetting->set(UKUI_BRIGHTNESS_KEY, value);
    }
    return;
}



SliderButtonIntel::SliderButtonIntel(QWidget *parent) : QSlider(parent)
{
    setOrientation(Qt::Orientation::Vertical);
    setMaximum(100);
    setMinimumHeight(230);
    setMinimumWidth(40);

    setStyleSheet(
           "QSlider::groove:Vertical {"
            "border: 0px none;"
            "background: #F0F0F0;"
            "height: 230px;"
            "width: 40px;"
            "border-radius: 8px;"
            "}"

            "QSlider::handle:Vertical {"
            "background: #2FB3E8;"
            "border: 0px none;"
            "width: 50px;"
            "height: 25px;"
            "border-radius: 8px;"
            "margin: 0px 0;"
            "border-image:url(:/image/abcd.png);"
            "}"

            "QSlider::add-page:Vertical {"
            "background: #2FB3E8;"
            "border-radius: 8px;"
            "}"

            "QSlider::sub-page:horizontal {"
            "background: #F6F6F6;"
            "border-radius: 8px;"
            "}"
        );

}

void SliderButtonIntel::mousePressEvent(QMouseEvent *e)
{
    if(e->button()==Qt::LeftButton) {
          clickState = true;
          emit  ycoordinate(e->y());
    }
}

void SliderButtonIntel::mouseReleaseEvent(QMouseEvent *event)
{
    if(event->button() == Qt::LeftButton) {
        clickState = false;
    }
}

void SliderButtonIntel::mouseMoveEvent(QMouseEvent *event)
{
    if(clickState) {
        i++ ;
        if(i==5){
            i=0;
            if(event->y()<=0) {
                emit  ycoordinate(0);
            }
            if(event->y()>=230) {
                emit  ycoordinate(230);
            }
            if(event->y()>0 && event->y()<230) {
                emit  ycoordinate(event->y());
            }
        }
    }
}
